[![CI](https://github.com/appsembler/site-configuration-client/actions/workflows/tests.yml/badge.svg)](https://github.com/appsembler/site-configuration-client/actions/workflows/tests.yml)

# Site Configuration Client
REST API client for the Site Configuration service.


# Compatibility
This package tested with both Python 3.9 and Python 3.5.

It has few required and optional dependencies:

 - **`requests`:** Required. Explicitly specified in `setup.py`
 - **`django`:** Optional. Tested to work with both Django 3 and Django 2.
 - **`google-cloud-storage`:** Tested with version 1.x.

For the exact versions please refer to both `setup.py` and the `requirements` directory.
